@@ -141,7 +141,7 @@ camel_kolab_imapx_provider_module_init (void)
 		g_error_free (tmp_err);
 	}
 	/* last resort... */
-	g_assert (imapx_provider != NULL);
+	g_return_if_fail (imapx_provider != NULL);
 
 	kolab_provider.object_types[CAMEL_PROVIDER_STORE] = camel_kolab_imapx_store_get_type ();
 	kolab_provider.object_types[CAMEL_PROVIDER_TRANSPORT] = G_TYPE_INVALID;
