@@ -273,10 +273,11 @@ kolab_backend_delete_resource_sync (ECollectionBackend *backend,
                                     GCancellable *cancellable,
                                     GError **error)
 {
-	KolabMailAccess *koma;
-	ESourceResource *extension;
-	const gchar *extension_name;
-	gchar *folder_path;
+	KolabMailAccess *koma = NULL;
+	ESourceRegistryServer *server = NULL;
+	ESourceResource *extension = NULL;
+	const gchar *extension_name = NULL;
+	gchar *folder_path = NULL;
 	gboolean success = FALSE;
 
 	koma = e_kolab_backend_ref_mail_access_sync (
@@ -306,7 +307,14 @@ kolab_backend_delete_resource_sync (ECollectionBackend *backend,
 
 	g_free (folder_path);
 
-exit:
+	if (! success)
+		goto exit;
+
+	server = e_collection_backend_ref_server (backend);
+	e_source_registry_server_remove_source (server, source);
+	g_object_unref (server);
+
+ exit:
 	if (koma != NULL)
 		g_object_unref (koma);
 
@@ -357,7 +365,6 @@ e_kolab_backend_init (EKolabBackend *backend)
 
 	/* init subsystems (these are no-ops if already called before) */
 	kolab_util_glib_init ();
-	kolab_util_folder_init ();
 	/* Initialize Camel and NSS.  If we fail here, there's not
 	 * much else to do but abort the whole service immediately. */
 	if (!kolab_util_camel_init (&error)) {
@@ -633,6 +640,10 @@ e_kolab_backend_sync_folders_sync (EKolabBackend *backend,
 		list = e_collection_backend_claim_all_resources (col_backend);
 
 		for (link = list; link != NULL; link = g_list_next (link))
+			/* FIXME should we set the source deletable here
+			 * itself, though trying to remove a source while
+			 * in offline mode will fail?
+			 */
 			e_source_registry_server_add_source (
 				server, E_SOURCE (link->data));
 
@@ -669,6 +680,7 @@ e_kolab_backend_sync_folders_sync (EKolabBackend *backend,
 		source = e_kolab_backend_new_child (backend, desc);
 
 		if (source != NULL) {
+			e_server_side_source_set_remote_deletable (E_SERVER_SIDE_SOURCE (source), TRUE);
 			e_source_registry_server_add_source (server, source);
 			g_object_unref (source);
 		}
