@@ -46,15 +46,21 @@ struct _KolabFolderMetaUIWidgets {
 	GtkWidget *container;
 	/* sub-widgets of container - folder type */
 	GtkWidget *frame_type_select;
+	GHashTable *folder_type_map;
 	GSList *radio_group;
-	GtkWidget *radio_btn_type_mail;
-	GtkWidget *radio_btn_type_calendar;
-	GtkWidget *radio_btn_type_memos;
-	GtkWidget *radio_btn_type_tasks;
-	GtkWidget *radio_btn_type_contacts;
+	guint radio_btn_handler_id[5];
+	GtkWidget *radio_btn_type[5];
+#if 0
+	GtkWidget *radio_btn_type_mail;     /* 0 */
+	GtkWidget *radio_btn_type_calendar; /* 1 */
+	GtkWidget *radio_btn_type_memos;    /* 2 */
+	GtkWidget *radio_btn_type_tasks;    /* 3 */
+	GtkWidget *radio_btn_type_contacts; /* 4 */
+#endif
 	/* sub-widgets of container - folder options */
 	GtkWidget *frame_options;
 	GtkWidget *chk_btn_show_all;
+	guint chk_btn_show_all_handler_id;
 };
 
 typedef struct _KolabFolderMetaUIData KolabFolderMetaUIData;
@@ -79,9 +85,13 @@ void
 e_kolab_folder_metadata_ui_update_from_uidata (KolabFolderMetaUIData *uidata);
 
 gboolean
-e_kolab_folder_metadata_ui_query_metadata (KolabFolderMetaUIData *uidata,
-                                           GCancellable *cancellable,
-                                           GError **err);
+e_kolab_folder_metadata_ui_query_store (KolabFolderMetaUIData *uidata,
+                                        GCancellable *cancellable,
+                                        GError **err);
+gboolean
+e_kolab_folder_metadata_ui_write_store (KolabFolderMetaUIData *uidata,
+                                        GCancellable *cancellable,
+                                        GError **err);
 
 /*----------------------------------------------------------------------------*/
 
