@@ -430,9 +430,9 @@ e_kolab_folder_permissions_ui_update_from_uidata (KolabFolderPermUIData *uidata)
 }
 
 gboolean
-e_kolab_folder_permissions_ui_query_acl (KolabFolderPermUIData *uidata,
-                                         GCancellable *cancellable,
-                                         GError **err)
+e_kolab_folder_permissions_ui_query_store (KolabFolderPermUIData *uidata,
+                                           GCancellable *cancellable,
+                                           GError **err)
 {
 	g_return_val_if_fail (uidata != NULL, FALSE);
 	/* cancellable may be NULL */
@@ -442,4 +442,20 @@ e_kolab_folder_permissions_ui_query_acl (KolabFolderPermUIData *uidata,
 	return TRUE;
 }
 
+gboolean
+e_kolab_folder_permissions_ui_write_store (KolabFolderPermUIData *uidata,
+                                           GCancellable *cancellable,
+                                           GError **err)
+{
+	g_return_val_if_fail (uidata != NULL, FALSE);
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	g_return_val_if_fail (E_IS_SHELL_VIEW (uidata->shell_view), FALSE);
+	g_return_val_if_fail (uidata->permissions != NULL, FALSE);
+
+	g_warning ("%s: FIXME implement me", __func__);
+	return TRUE;
+}
+
 /*----------------------------------------------------------------------------*/
