@@ -384,9 +384,9 @@ kolab_folder_prop_ui_query_metadata (KolabFolderPropUIData *uidata,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	ok = e_kolab_folder_metadata_ui_query_metadata (uidata->meta_ui_data,
-	                                                cancellable,
-	                                                &tmp_err);
+	ok = e_kolab_folder_metadata_ui_query_store (uidata->meta_ui_data,
+	                                             cancellable,
+	                                             &tmp_err);
 	if (tmp_err != NULL)
 		g_propagate_error (err, tmp_err);
 
@@ -405,9 +405,9 @@ kolab_folder_prop_ui_query_acl (KolabFolderPropUIData *uidata,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	ok = e_kolab_folder_permissions_ui_query_acl (uidata->perm_ui_data,
-	                                              cancellable,
-	                                              &tmp_err);
+	ok = e_kolab_folder_permissions_ui_query_store (uidata->perm_ui_data,
+	                                                cancellable,
+	                                                &tmp_err);
 	if (tmp_err != NULL)
 		g_propagate_error (err, tmp_err);
 
