@@ -34,6 +34,10 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <shell/e-shell-view.h>
+
+#include <libekolab/camel-kolab-imapx-store.h>
+
 /*----------------------------------------------------------------------------*/
 
 GtkWidget*
@@ -44,6 +48,26 @@ GtkWidget*
 e_kolab_plugin_util_ui_selected_folder_widget (const gchar *foldername,
                                                const gchar *sourcename);
 
+gboolean
+e_kolab_plugin_util_ui_get_selected_source (EShellView *shell_view,
+                                            ESource **selected_source);
+
+gboolean
+e_kolab_plugin_util_ui_get_selected_store (EShellView *shell_view,
+                                           CamelKolabIMAPXStore **kstore,
+                                           gchar **selected_path);
+
+gchar*
+e_kolab_plugin_util_ui_get_selected_path (EShellView *shell_view,
+                                          gboolean *is_kolab_account_node,
+                                          gboolean *is_kolab_folder_node);
+
+gchar*
+e_kolab_plugin_util_ui_get_selected_sourcename (EShellView *shell_view);
+
+gchar*
+e_kolab_plugin_util_ui_get_selected_foldername (EShellView *shell_view);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _E_KOLAB_PLUGIN_UTIL_H_ */
