@@ -77,6 +77,9 @@ imapx_extd_server_untagged_acl (CamelIMAPXServer *is,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	(void)stream; /* FIXME */
+	(void)cancellable; /* FIXME */
+	
 	/* FIXME implement me */
 	g_assert_not_reached ();
 
@@ -93,6 +96,9 @@ imapx_extd_server_untagged_myrights (CamelIMAPXServer *is,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	(void)stream; /* FIXME */
+	(void)cancellable; /* FIXME */
+	
 	/* FIXME implement me */
 	g_assert_not_reached ();
 
@@ -123,6 +129,8 @@ camel_imapx_extd_server_get_myrights (CamelIMAPXServer *is,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	(void)cancellable; /* FIXME */
+		
 	/* FIXME implement me */
 	g_assert_not_reached ();
 
@@ -140,6 +148,8 @@ camel_imapx_extd_server_get_acl (CamelIMAPXServer *is,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	(void)cancellable; /* FIXME */
+	
 	/* FIXME implement me */
 	g_assert_not_reached ();
 
@@ -157,6 +167,8 @@ camel_imapx_extd_server_set_acl (CamelIMAPXServer *is,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	(void)cancellable; /* FIXME */
+	
 	/* FIXME implement me */
 	g_assert_not_reached ();
 
