@@ -260,9 +260,10 @@ imapx_extd_store_create_folder_sync (CamelStore *self,
 	                                             foldername,
 	                                             cancellable,
 	                                             err);
-	/* FIXME set annotation data on server */
-	g_warning ("%s()[%u] FIXME set annotation data on server",
-	           __func__, __LINE__);
+	/* the folder annotation needs to be set by the
+	 * class which uses CamelIMAPXExtdStore (i.e.,
+	 * CamelKolabIMAPXStore)
+	 */
 
 	return fi;
 }
@@ -273,6 +274,9 @@ imapx_extd_store_delete_folder_sync (CamelStore *self,
                                      GCancellable *cancellable,
                                      GError **err)
 {
+	CamelIMAPXExtdStore *myself = NULL;
+	CamelIMAPXExtdStorePrivate *priv = NULL;
+	
 	gboolean ok = FALSE;
 
 	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
@@ -284,11 +288,20 @@ imapx_extd_store_delete_folder_sync (CamelStore *self,
 	                                             foldername,
 	                                             cancellable,
 	                                             err);
-
-	/* FIXME delete annotation data from server */
-	g_warning ("%s()[%u] FIXME delete annotation data from server",
-	           __func__, __LINE__);
-
+	if (ok) {
+		myself = CAMEL_IMAPX_EXTD_STORE (self);
+		priv = CAMEL_IMAPX_EXTD_STORE_PRIVATE (myself);
+		
+		/* delete folder metadata entry from our
+		 * hash table so we will not return a wrong
+		 * folder annotation if a folder with the
+		 * same name but different annotation gets
+		 * created later on
+		 */
+		(void) camel_imapx_metadata_remove_metadata (priv->md,
+		                                             foldername);
+	}
+	
 	return ok;
 }
 
