@@ -179,6 +179,10 @@ CamelImapxMetadataAttrib*
 camel_imapx_metadata_get_attrib_from_metadata (CamelImapxMetadata *md,
                                                CamelImapxMetadataSpec *spec);
 
+gboolean
+camel_imapx_metadata_remove_metadata (CamelImapxMetadata *md,
+                                      const gchar *mailbox_name);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _CAMEL_IMAPX_METADATA_H_ */
