@@ -388,12 +388,17 @@ imapx_store_set_foldertype (CamelKolabIMAPXStore *self,
 	/* create local CamelImapxMetadata for setting type */
 	acc = CAMEL_IMAPX_METADATA_ACCESS_SHARED;
 	ma = camel_imapx_metadata_attrib_new ();
-	ma->type[acc] = CAMEL_IMAPX_METADATA_ATTRIB_TYPE_UTF8;
-	typestring = kolab_util_folder_type_get_string (foldertype);
-	ma->data[acc] = g_byte_array_new ();
-	g_byte_array_append (ma->data[acc],
-	                     (guchar *) g_strdup (typestring),
-	                     strlen (typestring) + 1);
+	if (foldertype == KOLAB_FOLDER_TYPE_UNKNOWN) {
+		/* for unsetting the annotation */
+		ma->type[acc] = CAMEL_IMAPX_METADATA_ATTRIB_TYPE_NIL;
+	} else {
+		ma->type[acc] = CAMEL_IMAPX_METADATA_ATTRIB_TYPE_UTF8;
+		typestring = kolab_util_folder_type_get_string (foldertype);
+		ma->data[acc] = g_byte_array_new ();
+		g_byte_array_append (ma->data[acc],
+		                     (guchar *) g_strdup (typestring),
+		                     (guint) strlen (typestring) + 1);
+	}
 	me = camel_imapx_metadata_entry_new ();
 	g_hash_table_insert (me->attributes,
 	                     g_strdup ("value"),
@@ -409,9 +414,9 @@ imapx_store_set_foldertype (CamelKolabIMAPXStore *self,
 
 	/* set folder type on the server */
 	metadata_ok = camel_imapx_extd_store_set_metadata (es,
-	                                                    md,
-	                                                    cancellable,
-	                                                    &tmp_err);
+	                                                   md,
+	                                                   cancellable,
+	                                                   &tmp_err);
 	if (! metadata_ok) {
 		camel_imapx_metadata_free (md);
 		g_propagate_error (err, tmp_err);
@@ -601,7 +606,7 @@ imapx_store_show_all_folders (CamelKolabIMAPXStore *self,
                               GCancellable *cancellable,
                               GError **err)
 {
-	CamelKolabIMAPXStorePrivate *priv = NULL;
+	/* CamelKolabIMAPXStorePrivate *priv = NULL; */
 	CamelFolderInfo *fi = NULL;
 	CamelFolderInfo *k_fi = NULL;
 	CamelStoreGetFolderInfoFlags flags = 0;
@@ -612,7 +617,7 @@ imapx_store_show_all_folders (CamelKolabIMAPXStore *self,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	priv = CAMEL_KOLAB_IMAPX_STORE_PRIVATE (self);
+	/* priv = CAMEL_KOLAB_IMAPX_STORE_PRIVATE (self); */
 
 	/* get info tree of all folders */
 	flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL;
@@ -917,15 +922,14 @@ kolab_imapx_store_create_folder_sync (CamelStore *self,
 	                                 priv->folder_create_type,
 	                                 cancellable,
 	                                 &tmp_err);
+	g_free (fullname);
 	if (! ok) {
-		g_warning ("%s: setting type [%i] for [%s] on server failed.",
-		           __func__, priv->folder_create_type, fullname);
-		g_free (fullname);
+		g_warning ("%s: setting type [%i] for '%s/%s' on server failed: %s",
+		           __func__, priv->folder_create_type, parentname, foldername, tmp_err->message);
 		camel_store_free_folder_info (self, fi);
 		g_propagate_error (err, tmp_err);
 		return NULL;
 	}
-	g_free (fullname);
 
 	k_fi = imapx_store_folder_info_build_restricted (myself,
 	                                                 fi,
@@ -948,6 +952,7 @@ kolab_imapx_store_delete_folder_sync (CamelStore *self,
                                       GCancellable *cancellable,
                                       GError **err)
 {
+	CamelKolabIMAPXStore *myself = NULL;
 	GError *tmp_err = NULL;
 	gboolean ok = FALSE;
 
@@ -957,6 +962,8 @@ kolab_imapx_store_delete_folder_sync (CamelStore *self,
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
+	myself = CAMEL_KOLAB_IMAPX_STORE (self);
+
 	ok = parent_store_class->delete_folder_sync (self,
 	                                             foldername,
 	                                             cancellable,
@@ -966,7 +973,20 @@ kolab_imapx_store_delete_folder_sync (CamelStore *self,
 		return FALSE;
 	}
 
-	/* FIXME remove metadata of deleted folder from CamelKolabIMAPXServer */
+	/* try to remove metadata of deleted folder from Kolab server
+	 * (failure is non-fatal, since the RFC recommends that servers
+	 * should delete the metadata for deleted foldersy)
+	 */
+	ok = imapx_store_set_foldertype (myself,
+	                                 foldername,
+	                                 KOLAB_FOLDER_TYPE_UNKNOWN,
+	                                 cancellable,
+	                                 &tmp_err);
+	if (! ok) {
+		g_debug ("%s: removing type annotation for '%s' on server failed: %s",
+		           __func__, foldername, tmp_err->message);
+		g_error_free (tmp_err);
+	}
 
 	return TRUE;
 }
