@@ -165,6 +165,10 @@ KolabMailAccessOpmodeID
 kolab_mail_access_get_opmode (KolabMailAccess *self,
                               GError **err);
 
+void
+kolab_mail_access_password_set_visible (KolabMailAccess *self,
+                                        gboolean visible);
+
 GList*
 kolab_mail_access_query_sources (KolabMailAccess *self,
                                  GError **err);
