@@ -630,8 +630,8 @@ mail_imap_client_update_folder (KolabMailImapClient *self,
 
 static GList*
 mail_imap_client_query_foldernames (KolabMailImapClient *self,
-                                    GCancellable *cancellable,
                                     gboolean do_updatedb,
+                                    GCancellable *cancellable,
                                     GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
@@ -769,6 +769,13 @@ mail_imap_client_store (KolabMailImapClient *self,
 		                                     cancellable,
 		                                     &tmp_err);
 
+		if (fi != NULL) {
+			camel_store_free_folder_info (CAMEL_STORE (priv->store), fi);
+		} else {
+			g_warning ("%s()[%u] Folder creation returned NULL CamelFolderInfo for '%s/%s'",
+			           __func__, __LINE__, path->parent_name, path->folder_name);
+		}
+
 		kolab_util_camel_imap_path_free (path);
 
 		/* restore previously-configured folder creation type */
@@ -784,8 +791,6 @@ mail_imap_client_store (KolabMailImapClient *self,
 		
 		if (tmp_err != NULL)
 			goto cleanup;
-
-		/* set folder type annotation */
 		
 		goto cleanup;
 	}
@@ -1433,8 +1438,8 @@ kolab_mail_imap_client_query_foldernames (KolabMailImapClient *self,
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
 	folder_list = mail_imap_client_query_foldernames (self,
-	                                                  cancellable,
 	                                                  TRUE, /* update SQlite DBs */
+	                                                  cancellable,
 	                                                  err);
 	return folder_list;
 }
@@ -1504,8 +1509,8 @@ kolab_mail_imap_client_query_folder_info_online (KolabMailImapClient *self,
 	}
 
 	folder_names = mail_imap_client_query_foldernames (self,
-	                                                   cancellable,
 	                                                   FALSE, /* do not update DBs */
+	                                                   cancellable,
 	                                                   &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
@@ -1702,41 +1707,129 @@ kolab_mail_imap_client_delete_folder (KolabMailImapClient *self,
                                       GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
+	CamelFolderInfo *fi = NULL;
+	CamelFolder *folder = NULL;
+	GError *tmp_err = NULL;
+	gboolean has_children = FALSE;
+	gboolean has_messages = FALSE;
+	gboolean ok = TRUE;
 
 	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
 	g_assert (foldername != NULL);
-	(void)cancellable; /* FIXME */ /* cancellable may be NULL */
+	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
 
 	g_assert (priv->is_up == TRUE);
 
-	/* TODO implement me */
+	fi = camel_kolab_imapx_store_get_folder_info_online (priv->store,
+	                                                     foldername,
+	                                                     CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL,
+	                                                     cancellable,
+	                                                     &tmp_err);
+	if (tmp_err != NULL)
+		goto exit;
 
-	return TRUE;
+	/* CamelFolderInfo->total is unreliable unless we down-sync folder,
+	 * if we need that information, we need to get CamelFolder
+	 */
+	has_children = (fi->child != NULL);
+
+	if (has_children)
+		goto folder_skip;
+	
+	folder = camel_store_get_folder_sync (CAMEL_STORE (priv->store),
+	                                      foldername,
+	                                      0,
+	                                      cancellable,
+	                                      &tmp_err);
+	
+	if (tmp_err != NULL)
+		goto exit;
+
+	ok = camel_folder_refresh_info_sync (folder,
+	                                     cancellable,
+	                                     &tmp_err);
+	if (! ok)
+		goto exit;
+
+	has_messages = (camel_folder_get_message_count (folder) > 0);
+
+ folder_skip:
+	
+	/* won't delete a folder which has subfolders or messages in it */
+	if (has_children || has_messages) {
+		g_set_error (&tmp_err,
+		             KOLAB_CAMEL_ERROR,
+		             KOLAB_CAMEL_ERROR_GENERIC,
+		             _("Refusing to delete non-empty folder %s"),
+		             foldername);
+		goto exit;
+	}
+
+	/* delete folder on server */
+	ok = camel_store_delete_folder_sync (CAMEL_STORE (priv->store),
+	                                     foldername,
+	                                     cancellable,
+	                                     &tmp_err);
+ exit:
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		ok = FALSE;
+	}
+
+	if (fi != NULL)
+		camel_store_free_folder_info (CAMEL_STORE (priv->store), fi);
+
+	if (folder)
+		g_object_unref (folder);
+	
+	return ok;
 }
 
 gboolean
 kolab_mail_imap_client_exists_folder (KolabMailImapClient *self,
                                       const gchar *foldername,
+                                      gboolean do_updatedb,
                                       GCancellable *cancellable,
                                       GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
+	GList *folders = NULL;
+	GList *folders_ptr = NULL;
+	GError *tmp_err = NULL;
+	gboolean exists = FALSE;
 
 	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
 	g_assert (foldername != NULL);
-	(void)cancellable; /* FIXME */ /* cancellable may be NULL */
+	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
 
 	g_assert (priv->is_up == TRUE);
 
-	/* TODO implement me */
+	folders = mail_imap_client_query_foldernames (self,
+	                                              do_updatedb,
+	                                              cancellable,
+	                                              &tmp_err);
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		return FALSE;
+	}
 
-	return TRUE;
+	folders_ptr = folders;
+	while (folders_ptr != NULL) {
+		exists = g_str_equal (folders_ptr->data, foldername);
+		if (exists)
+			break;
+		folders_ptr = g_list_next (folders_ptr);
+	}
+
+	kolab_util_glib_glist_free (folders);
+
+	return exists;
 }
 
 /*----------------------------------------------------------------------------*/
