@@ -73,27 +73,27 @@ typedef gboolean (*KolabSettingsHandlerBoolSetFunc) (KolabSettingsHandler*, gboo
 
 typedef gboolean (*KolabSettingsHandlerGetFunc) (KolabSettingsHandler*, GError**);
 
-static gboolean kolab_settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler*, GError**);
-static gboolean kolab_settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler*, gchar*, GError**);
-static gboolean kolab_settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler*, GError**);
-static gboolean kolab_settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler*, gchar*, GError**);
-static gboolean kolab_settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler*, GError**);
-static gboolean kolab_settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler*, gchar*, GError**);
-static gboolean kolab_settings_handler_uint_set_func_folder_context (KolabSettingsHandler*, guint value, GError**);
+static gboolean settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler*, GError**);
+static gboolean settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler*, gchar*, GError**);
+static gboolean settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler*, GError**);
+static gboolean settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler*, gchar*, GError**);
+static gboolean settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler*, GError**);
+static gboolean settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler*, gchar*, GError**);
+static gboolean settings_handler_uint_set_func_folder_context (KolabSettingsHandler*, guint value, GError**);
 
 static KolabSettingsHandlerGetFunc _kolab_settings_handler_char_get_funcs[] = {
-	kolab_settings_handler_char_get_func_camel_data_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_DATA_DIR */
-	kolab_settings_handler_char_get_func_camel_cache_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR */
-	kolab_settings_handler_char_get_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
+	settings_handler_char_get_func_camel_data_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_DATA_DIR */
+	settings_handler_char_get_func_camel_cache_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR */
+	settings_handler_char_get_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD */
 };
 
 static KolabSettingsHandlerCharSetFunc _kolab_settings_handler_char_set_funcs[] = {
-	kolab_settings_handler_char_set_func_camel_data_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_DATA_DIR */
-	kolab_settings_handler_char_set_func_camel_cache_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR */
-	kolab_settings_handler_char_set_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
+	settings_handler_char_set_func_camel_data_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_DATA_DIR */
+	settings_handler_char_set_func_camel_cache_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR */
+	settings_handler_char_set_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD */
@@ -104,13 +104,13 @@ static KolabSettingsHandlerGetFunc _kolab_settings_handler_uint_get_funcs[] = {
 };
 
 static KolabSettingsHandlerUintSetFunc _kolab_settings_handler_uint_set_funcs[] = {
-	kolab_settings_handler_uint_set_func_folder_context /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
+	settings_handler_uint_set_func_folder_context /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
 };
 
 /*----------------------------------------------------------------------------*/
 
 static gboolean
-kolab_settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self, GError **err)
+settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self, GError **err)
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 	KolabFolderContextID context = KOLAB_FOLDER_CONTEXT_INVAL;
@@ -165,7 +165,7 @@ kolab_settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self,
 }
 
 static gboolean
-kolab_settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self, GError **err)
+settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self, GError **err)
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 	KolabFolderContextID context = KOLAB_FOLDER_CONTEXT_INVAL;
@@ -220,7 +220,7 @@ kolab_settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self
 }
 
 static gboolean
-kolab_settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self, gchar *value, GError **err)
+settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self, gchar *value, GError **err)
 {
 	(void)self;
 	(void)value;
@@ -232,7 +232,7 @@ kolab_settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self,
 }
 
 static gboolean
-kolab_settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler *self, gchar *value, GError **err)
+settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler *self, gchar *value, GError **err)
 {
 	(void)self;
 	(void)value;
@@ -245,7 +245,7 @@ kolab_settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler *self
 }
 
 static gboolean
-kolab_settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *self, GError **err)
+settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *self, GError **err)
 {
 	KolabSettingsHandlerPrivate *priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 	gboolean ok = FALSE;
@@ -258,7 +258,7 @@ kolab_settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *sel
 	if (priv_config_dir != NULL)
 		return TRUE;
 
-	ok = kolab_settings_handler_char_get_func_camel_data_dir (self, &tmp_err);
+	ok = settings_handler_char_get_func_camel_data_dir (self, &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -283,7 +283,7 @@ kolab_settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *sel
 }
 
 static gboolean
-kolab_settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *self, gchar *value, GError **err)
+settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *self, gchar *value, GError **err)
 {
 	(void)self;
 	(void)value;
@@ -295,7 +295,7 @@ kolab_settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *sel
 }
 
 static gboolean
-kolab_settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self, guint value, GError **err)
+settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self, guint value, GError **err)
 {
 	(void)self;
 	(void)value;
