@@ -43,9 +43,9 @@
 static void process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact);
 
 static void add_address (const EContact *e_contact, EContactAddress *e_address, I_contact* i_contact,
-		EContactField e_addr_type, GHashTable *k_store_hash);
+                         EContactField e_addr_type, GHashTable *k_store_hash);
 static void add_email (const EContact *e_contact, EContactField e_field,
-		I_contact* i_contact, gchar * email_str, GHashTable *k_store_hash);
+                       I_contact* i_contact, gchar * email_str, GHashTable *k_store_hash);
 static void add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *k_store_hash);
 static void add_custom_fields (const EContact *e_contact, I_contact* i_contact, GHashTable *k_store_hash);
 
@@ -53,7 +53,7 @@ static void add_custom_fields (const EContact *e_contact, I_contact* i_contact,
 static void kolab_store_handle_attachments(const EContact *e_contact, I_common* i_common);
 static GHashTable* kolab_store_read_values (const EContact *e_contact, I_contact* i_contact);
 static void kolab_store_restore_subnode_xml(I_contact *i_contact, gpointer parent_ptr,
-		const EContact *e_contact, EContactField e_field, GHashTable *k_store_hash);
+                                            const EContact *e_contact, EContactField e_field, GHashTable *k_store_hash);
 
 static Icontact_address_type address_type_e_to_i(EContactField e_addr_type);
 static Icontact_phone_type phone_type_e_to_i(GList *vcard_types);
@@ -156,7 +156,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		geo = e_contact_get (e_contact_dup, E_CONTACT_GEO);
 		if (geo) {
 			if (geo->latitude >= -90.0 && geo->latitude <= 90.0
-				&& geo->longitude >= -180.0 && geo->longitude <= 180.0) {
+			    && geo->longitude >= -180.0 && geo->longitude <= 180.0) {
 				i_contact->latitude = geo->latitude;
 				i_contact->longitude = geo->longitude;
 			}
@@ -295,7 +295,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			time_t *tt = NULL;
 
 			if (buffer[10] == 'T') /* get rid of 'T' in iso time stamp if neccessary */
-			        buffer[10] = ' ';
+				buffer[10] = ' ';
 
 			t = g_new0(struct tm, 1);
 			strptime(buffer, "%Y-%m-%d %H:%M:%S", t);
@@ -360,7 +360,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			if (memcmp (d, "\xFF\xD8", 2) == 0) {
 				i_contact->photo->name = g_strdup("kolab-picture.jpg");
 				i_contact->photo->mime_type = g_strdup("image/jpeg");
-			/* PNG signature (first eight bytes): 89 50 4E 47 0D 0A 1A 0A */
+				/* PNG signature (first eight bytes): 89 50 4E 47 0D 0A 1A 0A */
 			} else if (memcmp (d, "\x89PNG\r\n\x1A\n", 8) == 0) {
 				i_contact->photo->name = g_strdup("kolab-picture.png");
 				i_contact->photo->mime_type = g_strdup("image/png");
@@ -405,7 +405,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
  */
 static void
 add_address (const EContact *e_contact, EContactAddress *e_address, I_contact* i_contact,
-		EContactField e_addr_type, GHashTable *k_store_hash)
+             EContactField e_addr_type, GHashTable *k_store_hash)
 {
 	Address *addr = new_address ();
 
@@ -434,7 +434,7 @@ add_address (const EContact *e_contact, EContactAddress *e_address, I_contact* i
  */
 static void
 add_email (const EContact *e_contact, EContactField e_field,
-		I_contact* i_contact, gchar * email_str, GHashTable *k_store_hash)
+           I_contact* i_contact, gchar * email_str, GHashTable *k_store_hash)
 {
 	Email *structEmail = g_new0(Email, 1);
 
@@ -458,20 +458,17 @@ add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *
 	attrs = e_vcard_get_attributes (E_VCARD (e_contact));
 
 	/* for all attributes in vcard object */
-	for (attr = attrs; attr;)
-	{
+	for (attr = attrs; attr;) {
 		EVCardAttribute *a = attr->data;
 
 		/* do if it is a phone object */
-		if (!strcmp (EVC_TEL, e_vcard_attribute_get_name (a)))
-		{
+		if (!strcmp (EVC_TEL, e_vcard_attribute_get_name (a))) {
 			gchar* value = NULL;
 
 			GList *params = e_vcard_attribute_get_param (a, EVC_TYPE);
 			GList *param;
 			GList *type_list = NULL;
-			for (param = params; param; param = param->next)
-			{
+			for (param = params; param; param = param->next) {
 				EVCardAttributeParam *p = param->data;
 				type_list = g_list_append(type_list, p);
 			}
@@ -492,8 +489,7 @@ add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *
 				 * kolab store:
 				 * manual read from kolab store, maybe create a separate function for cases like this, when you have a vcard-attribute instead of e_object
 				 */
-				if (e_vcard_attribute_get_param(a, ICONTACT_KOLAB_STORE_ID) != NULL)
-				{
+				if (e_vcard_attribute_get_param(a, ICONTACT_KOLAB_STORE_ID) != NULL) {
 					GList *paramlist = e_vcard_attribute_get_param(a, ICONTACT_KOLAB_STORE_ID);
 					for (;paramlist != NULL; paramlist = paramlist->next) {
 						EVCardAttributeParam *eparam = paramlist->data;
@@ -584,11 +580,9 @@ add_custom_fields (const EContact *e_contact, I_contact* i_contact, GHashTable *
 		 * kolab store:
 		 * manual read from kolab store, maybe create a separate function for cases like this, when you have a vcard-attribute instead of e_object
 		 */
-		if (e_vcard_attribute_get_param(a, ICONTACT_KOLAB_STORE_ID) != NULL)
-		{
+		if (e_vcard_attribute_get_param(a, ICONTACT_KOLAB_STORE_ID) != NULL) {
 			GList *paramlist = e_vcard_attribute_get_param(a, ICONTACT_KOLAB_STORE_ID);
-			for (;paramlist != NULL; paramlist = paramlist->next)
-			{
+			for (;paramlist != NULL; paramlist = paramlist->next) {
 				EVCardAttributeParam *eparam = paramlist->data;
 
 				if (eparam != NULL) {
@@ -730,7 +724,7 @@ kolab_store_read_values (const EContact *e_contact, I_contact* i_contact)
  */
 static void
 kolab_store_restore_subnode_xml(I_contact *i_contact, gpointer parent_ptr,
-		const EContact *e_contact, EContactField e_field, GHashTable *k_store_hash)
+                                const EContact *e_contact, EContactField e_field, GHashTable *k_store_hash)
 {
 	gchar *e_value = NULL;
 	GList *e_attr_list = NULL;
@@ -791,13 +785,13 @@ static Icontact_address_type
 address_type_e_to_i(EContactField e_addr_type)
 {
 	switch (e_addr_type) {
-		case E_CONTACT_ADDRESS_HOME:
-			return ICONTACT_ADDR_TYPE_HOME;
-		case E_CONTACT_ADDRESS_WORK:
-			return ICONTACT_ADDR_TYPE_BUSINESS;
-		case E_CONTACT_ADDRESS_LABEL_OTHER:
-		default:
-			return ICONTACT_ADDR_TYPE_OTHER;
+	case E_CONTACT_ADDRESS_HOME:
+		return ICONTACT_ADDR_TYPE_HOME;
+	case E_CONTACT_ADDRESS_WORK:
+		return ICONTACT_ADDR_TYPE_BUSINESS;
+	case E_CONTACT_ADDRESS_LABEL_OTHER:
+	default:
+		return ICONTACT_ADDR_TYPE_OTHER;
 	}
 }
 
