@@ -54,15 +54,17 @@ log_evolution_ical (const gchar *message, const ECalComponentWithTZ* epim)
 	icalcomponent *ical_vevent = e_cal_component_get_icalcomponent ((ECalComponent*) epim->maincomp);
 	icalcomponent *ical_vcal = icalcomponent_new_vcalendar ();
 	icalcomponent *ical_vtz = NULL;
+	const gchar *ical_str = NULL;
+
 	if (epim->timezone != NULL) {
 		ical_vtz = e_cal_component_get_icalcomponent ((ECalComponent*) epim->timezone);
 		icalcomponent_add_component (ical_vcal, ical_vtz);
 	}
 	icalcomponent_add_component (ical_vcal, ical_vevent);
 
-	gchar *ical_str = icalcomponent_as_ical_string (ical_vcal);
+	/* memory returned by *_as_ical_string() is owned by libical */
+	ical_str = icalcomponent_as_ical_string (ical_vcal);
 	log_debug("%s\n%s", message, ical_str);
-	g_free(ical_str);
 
 	if (ical_vtz != NULL)
 		icalcomponent_remove_component (ical_vcal, ical_vtz);
