@@ -37,37 +37,48 @@
 #include "kolab-util-camel.h"
 
 /*----------------------------------------------------------------------------*/
-/* Camel init/shutdown */
+/* local statics */
 
-gboolean
-kolab_util_camel_init (GError **err)
+static gpointer
+util_camel_init_fn (gpointer data)
 {
-	static gboolean is_initialized = FALSE;
-
+	GError **err = (GError **) (&data);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	if (is_initialized == TRUE)
-		return TRUE;
-
-	/* GLib must be initialized first */
-	kolab_util_glib_init ();
-
 	/* init Camel subsystem */
 	if (camel_init (e_get_user_data_dir (), TRUE) != 0) {
 		g_set_error (err,
 		             KOLAB_CAMEL_ERROR,
 		             KOLAB_CAMEL_ERROR_GENERIC,
 		             _("Failed to initialize Camel subsystem"));
-		return FALSE;
+		return (gpointer) 1;
 	}
 
 	/* init the CamelProvider system */
 	camel_provider_init ();
 
-	is_initialized = TRUE;
-
 	g_debug ("%s: camel system initialized", __func__);
 
+	return NULL; /* ok */
+}
+
+/*----------------------------------------------------------------------------*/
+/* Camel init/shutdown */
+
+gboolean
+kolab_util_camel_init (GError **err)
+{
+	static GOnce my_once = G_ONCE_INIT;
+
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	g_once (&my_once,
+	        util_camel_init_fn,
+	        (gpointer) *err);
+
+	if (my_once.retval != NULL)
+		return FALSE;
+
 	return TRUE;
 }
 
