@@ -56,42 +56,32 @@ static gchar *kolab_folder_type_inv_map[] = {
 
 static KolabFolderTypeID kolab_folder_type_nums[KOLAB_FOLDER_LAST_TYPE];
 static GHashTable *kolab_folder_type_map = NULL;
-static gboolean kolab_util_folder_is_initialized = FALSE;
+static GMutex init_lock;
 
 /*----------------------------------------------------------------------------*/
 
-static gpointer
-util_folder_type_map_init (gpointer data)
+static void
+util_folder_init (void)
 {
 	gint ii = 0;
 
-	(void)data;
-	
-	kolab_folder_type_map = g_hash_table_new (g_str_hash, g_str_equal);
-	for (ii = 0; ii < KOLAB_FOLDER_LAST_TYPE; ii++) {
-		kolab_folder_type_nums[ii] = ii;
-		g_hash_table_insert (kolab_folder_type_map,
-		                     kolab_folder_type_inv_map[ii],
-		                     &(kolab_folder_type_nums[ii]));
-	}
+	g_mutex_lock (&init_lock);
 
-	kolab_util_folder_is_initialized = TRUE;
+	if (kolab_folder_type_map == NULL) {
+		kolab_folder_type_map = g_hash_table_new (g_str_hash, g_str_equal);
+		for (ii = 0; ii < KOLAB_FOLDER_LAST_TYPE; ii++) {
+			kolab_folder_type_nums[ii] = ii;
+			g_hash_table_insert (kolab_folder_type_map,
+			                     kolab_folder_type_inv_map[ii],
+			                     &(kolab_folder_type_nums[ii]));
+		}
+	}
 	
-	return NULL;
+	g_mutex_unlock (&init_lock);
 }
 
 /*----------------------------------------------------------------------------*/
 
-void
-kolab_util_folder_init (void)
-{
-	static GOnce my_once = G_ONCE_INIT;
-
-	g_once (&my_once,
-	        util_folder_type_map_init,
-	        NULL);
-}
-
 KolabFolderTypeID
 kolab_util_folder_type_get_id (const gchar *typestring)
 {
@@ -102,9 +92,10 @@ kolab_util_folder_type_get_id (const gchar *typestring)
 	gpointer map_entry = NULL;
 	KolabFolderTypeID id = KOLAB_FOLDER_TYPE_INVAL;
 
-	g_assert (kolab_util_folder_is_initialized);
 	g_assert (typestring != NULL);
 
+	util_folder_init ();
+	
 	map_entry = g_hash_table_lookup (kolab_folder_type_map, typestring);
 
 	if (map_entry == NULL)
@@ -117,16 +108,18 @@ kolab_util_folder_type_get_id (const gchar *typestring)
 const gchar*
 kolab_util_folder_type_get_string (KolabFolderTypeID foldertype)
 {
-	g_assert (kolab_util_folder_is_initialized);
 	g_assert (foldertype < KOLAB_FOLDER_LAST_TYPE);
+
+	util_folder_init ();
+	
 	return kolab_folder_type_inv_map[foldertype];
 }
 
+/*----------------------------------------------------------------------------*/
+
 KolabFolderContextID
 kolab_util_folder_type_map_to_context_id (KolabFolderTypeID type_id)
 {
-	g_assert (kolab_util_folder_is_initialized);
-
 	/* TODO better handling here */
 	g_assert ((type_id > KOLAB_FOLDER_TYPE_INVAL) &&
 	          (type_id < KOLAB_FOLDER_LAST_TYPE));
@@ -146,8 +139,6 @@ gboolean
 kolab_util_folder_type_match_with_context_id (KolabFolderTypeID type_id,
                                               KolabFolderContextID context_id)
 {
-	g_assert (kolab_util_folder_is_initialized);
-
 	/* TODO better handling here */
 	g_assert ((type_id > KOLAB_FOLDER_TYPE_INVAL) &&
 	          (type_id < KOLAB_FOLDER_LAST_TYPE));
@@ -178,6 +169,8 @@ kolab_util_folder_type_match_with_context_id (KolabFolderTypeID type_id,
 	return TRUE;
 }
 
+/*----------------------------------------------------------------------------*/
+
 KolabFolderDescriptor*
 kolab_util_folder_descriptor_new (const gchar *foldername,
                                   KolabFolderTypeID type_id)
@@ -221,3 +214,95 @@ kolab_util_folder_descriptor_glist_free (GList *list)
 }
 
 /*----------------------------------------------------------------------------*/
+
+GHashTable*
+kolab_util_folder_timestamp_table_new (void)
+{
+	GHashTable *table =
+		g_hash_table_new_full (g_str_hash,
+		                       g_str_equal,
+		                       g_free,
+		                       g_free);
+	return table;
+}
+
+void
+kolab_util_folder_timestamp_table_free (GHashTable *table)
+{
+	g_return_if_fail (table != NULL);
+	g_hash_table_destroy (table);
+}
+
+void
+kolab_util_folder_timestamp_table_update (GHashTable *table,
+                                          const gchar *foldername)
+{
+	gint64 timestamp = 0;
+	gint64 *stamp_ptr = NULL;
+	
+	g_return_if_fail (table != NULL);
+	g_return_if_fail (foldername != NULL);
+
+	timestamp = g_get_monotonic_time ();
+	g_return_if_fail (timestamp >= 0);
+	
+	stamp_ptr = (gint64*) g_malloc0 (sizeof (gint64));
+	g_return_if_fail (stamp_ptr != NULL);
+
+	*stamp_ptr = timestamp;
+
+	g_hash_table_replace (table,
+	                      g_strdup (foldername),
+	                      stamp_ptr);
+}
+
+gint64
+kolab_util_folder_timestamp_table_lookup (GHashTable *table,
+                                          const gchar *foldername)
+{
+	gint64 timestamp = 0;
+	gpointer stamp_ptr = NULL;
+
+	g_return_val_if_fail (table != NULL, -1);
+	g_return_val_if_fail (foldername != NULL, -1);
+
+	stamp_ptr = g_hash_table_lookup (table,
+	                                 foldername);
+	if (stamp_ptr == NULL)
+		return -1;
+
+	timestamp = *((gint64*) stamp_ptr);
+
+	return timestamp;
+}
+
+gint64
+kolab_util_folder_timestamp_table_msec_since_update (GHashTable *table,
+                                                     const gchar *foldername)
+{
+	gint64 timestamp_current = 0;
+	gint64 timestamp_latest = 0;
+	gint64 timestamp_diff = 0;
+
+	g_return_val_if_fail (table != NULL, -1);
+	g_return_val_if_fail (foldername != NULL, -1);
+
+	timestamp_current = g_get_monotonic_time ();
+	g_return_val_if_fail (timestamp_current >= 0, -1);
+
+	timestamp_latest =
+		kolab_util_folder_timestamp_table_lookup (table,
+		                                          foldername);
+	if (timestamp_latest < 0)
+		return -1;
+
+	timestamp_diff = timestamp_current - timestamp_latest;
+
+	if (timestamp_diff < 0)
+		timestamp_diff = -1;
+
+	return timestamp_diff;
+}
+
+/*----------------------------------------------------------------------------*/
+
