@@ -99,10 +99,9 @@ struct _KolabFolderDescriptor {
 	KolabFolderTypeID type_id;
 };
 
-/*----------------------------------------------------------------------------*/
+#define KOLAB_FOLDER_UPDATE_DELAY_MICROSECS ((gint64) 13000000)
 
-void
-kolab_util_folder_init (void);
+/*----------------------------------------------------------------------------*/
 
 KolabFolderTypeID
 kolab_util_folder_type_get_id (const gchar *typestring);
@@ -126,6 +125,24 @@ kolab_util_folder_descriptor_free (KolabFolderDescriptor *desc);
 void
 kolab_util_folder_descriptor_glist_free (GList *list);
 
+GHashTable*
+kolab_util_folder_timestamp_table_new (void);
+
+void
+kolab_util_folder_timestamp_table_free (GHashTable *table);
+
+void
+kolab_util_folder_timestamp_table_update (GHashTable *table,
+                                          const gchar *foldername);
+
+gint64
+kolab_util_folder_timestamp_table_lookup (GHashTable *table,
+                                          const gchar *foldername);
+
+gint64
+kolab_util_folder_timestamp_table_msec_since_update (GHashTable *table,
+                                                     const gchar *foldername);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _KOLAB_UTIL_FOLDER_ */
