@@ -34,11 +34,10 @@
 #include <glib.h>
 #include <stdlib.h>
 
-#include <camel/camel-kolab-stream.h>
-#include <camel/camel-kolab-session.h>
-
-#include <libecal/e-cal-component.h>
+#include <libecal/libecal.h>
 
+#include <libekolab/camel-kolab-session.h>
+#include <libekolabutil/camel-kolab-stream.h>
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-camel.h>
 #include <libekolabutil/kolab-util-http.h>
